==> billogram-foundation-2.4.0.tgz: package/modules/components/textbox/TextboxContainer.js <==
import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import textboxChange from './redux-actions/textboxChange';


const changeType = actionName('CHANGE');

export {
    changeType
};

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Textbox component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        propTypes: {
            path: PropTypes.string.isRequired,
            root: PropTypes.string.isRequired,
            // ---
            actionTypePrefix: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { focus, rawValue } = getComponentState(state, props);
        return {
            focus,
            value: rawValue
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'TEXTBOX';

        return {
            onChange: ({ rawValue, value }) => dispatch(textboxChange({ path, rawValue, root, type: changeType(actionTypePrefix), value }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};

==> billogram-foundation-3.11.0.tgz: package/modules/components/textbox/TextboxContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import textboxChange from './redux/textboxChange';


const changeType = actionName('CHANGE');

export {
    changeType
};

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Textbox component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { focus, rawValue } = getComponentState(state, props);
        return {
            focus,
            value: rawValue
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'TEXTBOX';

        return {
            onChange: ({ rawValue, value }) => dispatch(textboxChange({ custom, path, rawValue, root, type: changeType(actionTypePrefix), value }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};
